lib_llama_cpp_ffi
library
Typedefs
-
Dartggml_abort_callback_tFunction
= void Function(Pointer<Char> error_message)
-
-
Dartggml_abort_callbackFunction
= bool Function(Pointer<Void> data)
-
-
Dartggml_backend_comm_allreduce_tensor_tFunction
= bool Function(Pointer<Void> comm_ctx, Pointer<Pointer<ggml_tensor>> tensors)
-
-
Dartggml_backend_comm_free_tFunction
= void Function(Pointer<Void> comm_ctx)
-
-
Dartggml_backend_comm_init_tFunction
= Pointer<Void> Function(Pointer<ggml_backend_t> backends, int n_backends)
-
-
Dartggml_backend_eval_callbackFunction
= bool Function(int node_index, Pointer<ggml_tensor> t1, Pointer<ggml_tensor> t2, Pointer<Void> user_data)
-
-
Dartggml_backend_sched_eval_callbackFunction
= bool Function(Pointer<ggml_tensor> t, bool ask, Pointer<Void> user_data)
-
-
Dartggml_backend_set_abort_callback_tFunction
= void Function(ggml_backend_t backend, ggml_abort_callback abort_callback, Pointer<Void> abort_callback_data)
-
-
Dartggml_backend_set_n_threads_tFunction
= void Function(ggml_backend_t backend, int n_threads)
-
-
Dartggml_backend_split_buffer_type_tFunction
= ggml_backend_buffer_type_t Function(int main_device, Pointer<Float> tensor_split)
-
-
Dartggml_custom1_op_tFunction
= void Function(Pointer<ggml_tensor> dst, Pointer<ggml_tensor> a, int ith, int nth, Pointer<Void> userdata)
-
-
Dartggml_custom2_op_tFunction
= void Function(Pointer<ggml_tensor> dst, Pointer<ggml_tensor> a, Pointer<ggml_tensor> b, int ith, int nth, Pointer<Void> userdata)
-
-
Dartggml_custom3_op_tFunction
= void Function(Pointer<ggml_tensor> dst, Pointer<ggml_tensor> a, Pointer<ggml_tensor> b, Pointer<ggml_tensor> c, int ith, int nth, Pointer<Void> userdata)
-
-
Dartggml_custom_op_tFunction
= void Function(Pointer<ggml_tensor> dst, int ith, int nth, Pointer<Void> userdata)
-
-
Dartggml_fp16_t
= int
-
-
Dartggml_from_float_tFunction
= void Function(Pointer<Float> x, Pointer<Void> y, int k)
-
-
Dartggml_log_callbackFunction
= void Function(ggml_log_level level, Pointer<Char> text, Pointer<Void> user_data)
-
-
Dartggml_opt_epoch_callbackFunction
= void Function(bool train, ggml_opt_context_t opt_ctx, ggml_opt_dataset_t dataset, ggml_opt_result_t result, int ibatch, int ibatch_max, int t_start_us)
-
-
Dartggml_to_float_tFunction
= void Function(Pointer<Void> x, Pointer<Float> y, int k)
-
-
Dartggml_vec_dot_tFunction
= void Function(int n, Pointer<Float> s, int bs, Pointer<Void> x, int bx, Pointer<Void> y, int by, int nrc)
-
-
Dartllama_model_set_tensor_data_tFunction
= void Function(Pointer<ggml_tensor> tensor, Pointer<Void> userdata)
-
-
Dartllama_opt_param_filterFunction
= bool Function(Pointer<ggml_tensor> tensor, Pointer<Void> userdata)
-
-
Dartllama_pos
= int
-
-
Dartllama_progress_callbackFunction
= bool Function(double progress, Pointer<Void> user_data)
-
-
Dartllama_seq_id
= int
-
-
Dartllama_state_seq_flags
= int
-
-
Dartllama_token
= int
-
-
Dartllcs_task_id
= int
-
-
DynamicLibraryOpener
= DynamicLibrary Function(String path)
-
-
ggml_abort_callback
= Pointer<NativeFunction<ggml_abort_callbackFunction>>
-
Abort callback
If not NULL, called before ggml computation
If it returns true, the computation is aborted
-
ggml_abort_callback_t
= Pointer<NativeFunction<ggml_abort_callback_tFunction>>
-
Function type used in fatal error callbacks
-
ggml_abort_callback_tFunction
= Void Function(Pointer<Char> error_message)
-
-
ggml_abort_callbackFunction
= Bool Function(Pointer<Void> data)
-
-
ggml_backend_buffer_t
= Pointer<ggml_backend_buffer>
-
-
ggml_backend_buffer_type_t
= Pointer<ggml_backend_buffer_type>
-
-
ggml_backend_comm_allreduce_tensor_t
= Pointer<NativeFunction<ggml_backend_comm_allreduce_tensor_tFunction>>
-
-
ggml_backend_comm_allreduce_tensor_tFunction
= Bool Function(Pointer<Void> comm_ctx, Pointer<Pointer<ggml_tensor>> tensors)
-
-
ggml_backend_comm_free_t
= Pointer<NativeFunction<ggml_backend_comm_free_tFunction>>
-
-
ggml_backend_comm_free_tFunction
= Void Function(Pointer<Void> comm_ctx)
-
-
ggml_backend_comm_init_t
= Pointer<NativeFunction<ggml_backend_comm_init_tFunction>>
-
Context management and operations for faster communication between backends, used for tensor parallelism (meta backend)
-
ggml_backend_comm_init_tFunction
= Pointer<Void> Function(Pointer<ggml_backend_t> backends, Size n_backends)
-
-
Get additional buffer types provided by the device (returns a NULL-terminated array)
-
-
ggml_backend_dev_t
= Pointer<ggml_backend_device>
-
-
ggml_backend_eval_callback
= Pointer<NativeFunction<ggml_backend_eval_callbackFunction>>
-
-
ggml_backend_eval_callbackFunction
= Bool Function(Int node_index, Pointer<ggml_tensor> t1, Pointer<ggml_tensor> t2, Pointer<Void> user_data)
-
-
ggml_backend_event_t
= Pointer<ggml_backend_event>
-
-
ggml_backend_get_features_t
= Pointer<NativeFunction<ggml_backend_get_features_tFunction>>
-
-
ggml_backend_get_features_tFunction
= Pointer<ggml_backend_feature> Function(ggml_backend_reg_t reg)
-
-
ggml_backend_graph_plan_t
= Pointer<Void>
-
-
ggml_backend_meta_get_split_state_t
= Pointer<NativeFunction<ggml_backend_meta_get_split_state_tFunction>>
-
function to assign split states for statically allocated tensors, compute tensor split states will be assigned to be compatible:
-
ggml_backend_meta_get_split_state_tFunction
= ggml_backend_meta_split_state Function(Pointer<ggml_tensor> tensor, Pointer<Void> userdata)
-
-
ggml_backend_reg_t
= Pointer<ggml_backend_reg>
-
-
ggml_backend_sched_eval_callback
= Pointer<NativeFunction<ggml_backend_sched_eval_callbackFunction>>
-
Evaluation callback for each node in the graph (set with ggml_backend_sched_set_eval_callback)
when ask == true, the scheduler wants to know if the user wants to observe this node
this allows the scheduler to batch nodes together in order to evaluate them in a single call
-
ggml_backend_sched_eval_callbackFunction
= Bool Function(Pointer<ggml_tensor> t, Bool ask, Pointer<Void> user_data)
-
-
ggml_backend_sched_t
= Pointer<ggml_backend_sched>
-
The backend scheduler allows for multiple backend devices to be used together
Handles compute buffer allocation, assignment of tensors to backends, and copying of tensors between backends
The backends are selected based on:
-
ggml_backend_set_abort_callback_t
= Pointer<NativeFunction<ggml_backend_set_abort_callback_tFunction>>
-
Set the abort callback for the backend
-
ggml_backend_set_abort_callback_tFunction
= Void Function(ggml_backend_t backend, ggml_abort_callback abort_callback, Pointer<Void> abort_callback_data)
-
-
ggml_backend_set_n_threads_t
= Pointer<NativeFunction<ggml_backend_set_n_threads_tFunction>>
-
Set the number of threads for the backend
-
ggml_backend_set_n_threads_tFunction
= Void Function(ggml_backend_t backend, Int n_threads)
-
-
ggml_backend_split_buffer_type_t
= Pointer<NativeFunction<ggml_backend_split_buffer_type_tFunction>>
-
Split buffer type for tensor parallelism (old)
-
ggml_backend_split_buffer_type_tFunction
= ggml_backend_buffer_type_t Function(Int main_device, Pointer<Float> tensor_split)
-
-
ggml_backend_t
= Pointer<ggml_backend>
-
-
ggml_custom1_op_t
= Pointer<NativeFunction<ggml_custom1_op_tFunction>>
-
custom operators
-
ggml_custom1_op_tFunction
= Void Function(Pointer<ggml_tensor> dst, Pointer<ggml_tensor> a, Int ith, Int nth, Pointer<Void> userdata)
-
-
ggml_custom2_op_t
= Pointer<NativeFunction<ggml_custom2_op_tFunction>>
-
-
ggml_custom2_op_tFunction
= Void Function(Pointer<ggml_tensor> dst, Pointer<ggml_tensor> a, Pointer<ggml_tensor> b, Int ith, Int nth, Pointer<Void> userdata)
-
-
ggml_custom3_op_t
= Pointer<NativeFunction<ggml_custom3_op_tFunction>>
-
-
ggml_custom3_op_tFunction
= Void Function(Pointer<ggml_tensor> dst, Pointer<ggml_tensor> a, Pointer<ggml_tensor> b, Pointer<ggml_tensor> c, Int ith, Int nth, Pointer<Void> userdata)
-
-
ggml_custom_op_t
= Pointer<NativeFunction<ggml_custom_op_tFunction>>
-
-
ggml_custom_op_tFunction
= Void Function(Pointer<ggml_tensor> dst, Int ith, Int nth, Pointer<Void> userdata)
-
-
ggml_fp16_t
= Uint16
-
ieee 754-2008 half-precision float16
todo: make this not an integral type
-
ggml_from_float_t
= Pointer<NativeFunction<ggml_from_float_tFunction>>
-
-
ggml_from_float_tFunction
= Void Function(Pointer<Float> x, Pointer<Void> y, Int64 k)
-
-
ggml_gallocr_t
= Pointer<ggml_gallocr>
-
special tensor flags for use with the graph allocator:
ggml_set_input(): all input tensors are allocated at the beginning of the graph in non-overlapping addresses
ggml_set_output(): output tensors are never freed and never overwritten
-
ggml_guid_t
= Pointer<Pointer<Uint8>>
-
-
ggml_log_callback
= Pointer<NativeFunction<ggml_log_callbackFunction>>
-
TODO these functions were sandwiched in the old optimization interface, is there a better place for them?
-
ggml_log_callbackFunction
= Void Function(UnsignedInt level, Pointer<Char> text, Pointer<Void> user_data)
-
-
ggml_opt_context_t
= Pointer<ggml_opt_context>
-
-
ggml_opt_dataset_t
= Pointer<ggml_opt_dataset>
-
-
ggml_opt_epoch_callback
= Pointer<NativeFunction<ggml_opt_epoch_callbackFunction>>
-
signature for a callback while evaluating opt_ctx on dataset, called after an evaluation
-
ggml_opt_epoch_callbackFunction
= Void Function(Bool train, ggml_opt_context_t opt_ctx, ggml_opt_dataset_t dataset, ggml_opt_result_t result, Int64 ibatch, Int64 ibatch_max, Int64 t_start_us)
-
-
ggml_opt_get_optimizer_params
= Pointer<NativeFunction<ggml_opt_get_optimizer_paramsFunction>>
-
callback to calculate optimizer parameters prior to a backward pass
userdata can be used to pass arbitrary data
-
ggml_opt_get_optimizer_paramsFunction
= ggml_opt_optimizer_params Function(Pointer<Void> userdata)
-
-
ggml_opt_result_t
= Pointer<ggml_opt_result>
-
-
ggml_threadpool_t
= Pointer<ggml_threadpool>
-
-
ggml_to_float_t
= Pointer<NativeFunction<ggml_to_float_tFunction>>
-
-
ggml_to_float_tFunction
= Void Function(Pointer<Void> x, Pointer<Float> y, Int64 k)
-
-
ggml_vec_dot_t
= Pointer<NativeFunction<ggml_vec_dot_tFunction>>
-
Internal types and functions exposed for tests and benchmarks
-
ggml_vec_dot_tFunction
= Void Function(Int n, Pointer<Float> s, Size bs, Pointer<Void> x, Size bx, Pointer<Void> y, Size by, Int nrc)
-
-
llama_memory_t
= Pointer<llama_memory_i>
-
-
llama_model_set_tensor_data_t
= Pointer<NativeFunction<llama_model_set_tensor_data_tFunction>>
-
-
llama_model_set_tensor_data_tFunction
= Void Function(Pointer<ggml_tensor> tensor, Pointer<Void> userdata)
-
-
llama_opt_param_filter
= Pointer<NativeFunction<llama_opt_param_filterFunction>>
-
function that returns whether or not a given tensor contains trainable parameters
-
llama_opt_param_filterFunction
= Bool Function(Pointer<ggml_tensor> tensor, Pointer<Void> userdata)
-
-
llama_pos
= Int32
-
-
llama_progress_callback
= Pointer<NativeFunction<llama_progress_callbackFunction>>
-
-
llama_progress_callbackFunction
= Bool Function(Float progress, Pointer<Void> user_data)
-
-
llama_sampler_context_t
= Pointer<Void>
-
Sampling API
-
llama_seq_id
= Int32
-
-
llama_state_seq_flags
= Uint32
-
-
llama_token
= Int32
-
-
llcs_task_id
= Int64
-
-
OperatingSystemProvider
= String Function()
-