LlamaCppDynamicLibraryLoader class final

Constructors

LlamaCppDynamicLibraryLoader({DynamicLibraryOpener? openLibrary, OperatingSystemProvider? operatingSystem})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
open([String? path]) DynamicLibrary
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

defaultLibraryPathFor(String operatingSystem) String