LlamaModelHandle class final

Implemented types

Constructors

LlamaModelHandle.owned(Pointer<LlamaModel> pointer, {NativeFinalizer? finalizer, void release(Pointer<LlamaModel> pointer)?})
factory
LlamaModelHandle.unowned(Pointer<LlamaModel> pointer)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isClosed bool
no setterinherited
pointer Pointer<LlamaModel>
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited