ggml_log_callback typedef
TODO these functions were sandwiched in the old optimization interface, is there a better place for them?
Implementation
typedef ggml_log_callback =
ffi.Pointer<ffi.NativeFunction<ggml_log_callbackFunction>>;
TODO these functions were sandwiched in the old optimization interface, is there a better place for them?
typedef ggml_log_callback =
ffi.Pointer<ffi.NativeFunction<ggml_log_callbackFunction>>;