ggml_op_hint enum

op hint

Inheritance
Available extensions

Values

GGML_HINT_NONE → const ggml_op_hint
const ggml_op_hint(0)
GGML_HINT_SRC0_IS_HADAMARD → const ggml_op_hint
const ggml_op_hint(1)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromValue(int value) ggml_op_hint

Constants

values → const List<ggml_op_hint>
A constant List of the values in this enum, in order of their declaration.