ggml_opt_params class final

parameters for initializing a new optimization context

Inheritance
Implemented types
Available extensions

Constructors

ggml_opt_params()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
backend_sched ggml_backend_sched_t
defines which backends are used to construct the compute graphs
getter/setter pair
build_type ggml_opt_build_type
no setter
build_typeAsInt int
getter/setter pair
ctx_compute Pointer<ggml_context>
by default the forward graph needs to be reconstructed for each eval if ctx_compute, inputs, and outputs are set the graphs are instead allocated statically
getter/setter pair
get_opt_pars ggml_opt_get_optimizer_params
callback for calculating optimizer parameters
getter/setter pair
get_opt_pars_ud Pointer<Void>
userdata for calculating optimizer parameters
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
inputs Pointer<ggml_tensor>
getter/setter pair
loss_type ggml_opt_loss_type
no setter
loss_typeAsInt int
getter/setter pair
opt_period int
after how many gradient accumulation steps an optimizer step should be done
getter/setter pair
optimizer ggml_opt_optimizer_type
no setter
optimizerAsInt int
only GGML_OPT_OPTIMIZER_TYPE_ADAMW needs m, v momenta per parameter tensor
getter/setter pair
outputs Pointer<ggml_tensor>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited