llama_perf_context_data class final

Performance utils

NOTE: Used by llama.cpp examples/tools, avoid using in third-party apps. Instead, do your own performance measurements.

Inheritance
Implemented types
Available extensions

Constructors

llama_perf_context_data()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
hashCode int
The hash code for this object.
no setterinherited
n_eval int
number of generated tokens
getter/setter pair
n_p_eval int
number of prompt tokens
getter/setter pair
n_reused int
number of times a ggml compute graph had been reused
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
t_eval_ms double
time needed for generating tokens
getter/setter pair
t_load_ms double
time needed for loading the model
getter/setter pair
t_p_eval_ms double
time needed for processing the prompt
getter/setter pair
t_start_ms double
absolute start time
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited